DesktopProxyPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • DesktopProxyPlatform
Implementers

Constructors

DesktopProxyPlatform()
Constructs a DesktopProxyPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getProxyForUrl(Uri url) Future<Uri?>
Returns the proxy Uri for url, or null for a direct connection.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance DesktopProxyPlatform
The default instance of DesktopProxyPlatform to use.
getter/setter pair